"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = BottomTabsStack;
var _navigationUtils = require("./navigationUtils");
var React = _interopRequireWildcard(require("react"));
var _TabBar = _interopRequireDefault(require("./navigation/TabBar"));
var _TabBarItem = _interopRequireDefault(require("./navigation/TabBarItem"));
var _navigationReact = require("navigation-react");
var _NavigationStack = _interopRequireDefault(require("./navigation/NavigationStack"));
var _useBottomTabsStateNavigator = require("./navigation/useBottomTabsStateNavigator");
var _RidgeNavigationContext = _interopRequireDefault(require("./contexts/RidgeNavigationContext"));
var _OptimizedContext = _interopRequireWildcard(require("./contexts/OptimizedContext"));
var _BottomTabIndexContext = _interopRequireDefault(require("./contexts/BottomTabIndexContext"));
var _BottomTabBadgesContext = _interopRequireDefault(require("./contexts/BottomTabBadgesContext"));
var _useCurrentRoot = _interopRequireDefault(require("./useCurrentRoot"));
var _HiddenNavbarWithSwipeBack = _interopRequireDefault(require("./HiddenNavbarWithSwipeBack"));
var _BottomTabRefreshContext = _interopRequireDefault(require("./contexts/BottomTabRefreshContext"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
function BottomTabsStack() {
  const {
    currentRoot,
    currentRootKey
  } = (0, _useCurrentRoot.default)();
  const root = currentRoot;
  const {
    theme: {
      bottomBar: bottomTheme
    }
  } = React.useContext(_OptimizedContext.default);
  const {
    badges
  } = React.useContext(_BottomTabBadgesContext.default);
  React.useContext(_BottomTabRefreshContext.default);
  const {
    setBottomTabIndex,
    bottomTabIndex
  } = React.useContext(_BottomTabIndexContext.default);
  if (root.type !== 'bottomTabs') {
    return null;
  }
  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(_HiddenNavbarWithSwipeBack.default, null), /*#__PURE__*/React.createElement(_TabBar.default, {
    primary: true,
    bottomTabs: true,
    labelVisibilityMode: "labeled",
    tab: bottomTabIndex,
    onChangeTab: setBottomTabIndex,
    rippleColor: bottomTheme.rippleColor,
    unselectedTintColor: bottomTheme.textColor,
    barTintColor: bottomTheme.backgroundColor,
    selectedTintColor: bottomTheme.selectedTextColor,
    activeIndicatorColor: bottomTheme.activeIndicatorColor,
    scrollsToTop: bottomTheme.scrollsToTop
  }, root.children.map((tab, index) => {
    return /*#__PURE__*/React.createElement(_TabBarItem.default, {
      key: tab.path,
      title: tab.title(),
      image: bottomTabIndex === index ? tab.selectedIcon : tab.icon,
      badge: badges[tab.path],
      badgeColor: bottomTheme.badgeColor,
      fontFamily: bottomTheme.fontFamily,
      fontSize: bottomTheme.fontSize,
      fontWeight: bottomTheme.fontWeight,
      fontStyle: bottomTheme.fontStyle,
      testID: `bottomTab-${tab.child.path}`
    }, /*#__PURE__*/React.createElement(TabBarItemStack, {
      tab: tab,
      rootKey: currentRootKey
    }));
  })));
}
const TabBarItemStack = /*#__PURE__*/React.memo(_ref => {
  let {
    tab,
    rootKey
  } = _ref;
  const start = (0, _navigationUtils.getScreenKey)(rootKey, tab);
  const navigator = (0, _useBottomTabsStateNavigator.useBottomTabsStateNavigator)(start);
  const {
    theme: {
      layout
    }
  } = React.useContext(_RidgeNavigationContext.default);
  return /*#__PURE__*/React.createElement(_navigationReact.NavigationHandler, {
    stateNavigator: navigator
  }, /*#__PURE__*/React.createElement(_NavigationStack.default
  // underlayColor={layout.backgroundColor} // Disables touchables if returned from background
  , {
    backgroundColor: () => layout.backgroundColor,
    renderScene: (state, data) => {
      return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(_HiddenNavbarWithSwipeBack.default, null), /*#__PURE__*/React.createElement(_OptimizedContext.OptimizedContextProvider, {
        state: state,
        data: data
      }, state.renderScene()));
    }
  }));
});
//# sourceMappingURL=BottomTabsStack.js.map