"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = Link;
var React = _interopRequireWildcard(require("react"));
var _useNavigation = _interopRequireDefault(require("./useNavigation"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
function Link(_ref) {
  let {
    to,
    toBottomTab,
    params,
    children,
    onPress: onCustomPress,
    skipLinkBehaviourIfPressIsDefined,
    replace: isReplaceInsteadOfPush,
    refresh: isRefreshInsteadOfPush,
    ...rest
  } = _ref;
  const isPushing = React.useRef(false);
  const {
    push,
    replace,
    refresh,
    preload,
    preloadElement
  } = (0, _useNavigation.default)();
  const preloadElementInner = React.useCallback(() => {
    preloadElement(to);
  }, [preloadElement, to]);
  const onPress = React.useCallback(async event => {
    // we don't want to go to another screen but we do want preloading
    // behaviour of the Link component :)
    // e.g. a modal with same data dependencies as the list screen
    if (onCustomPress) {
      onCustomPress(event);
      return;
    }
    if (isPushing.current) {
      return;
    }
    isPushing.current = true;
    const options = {
      preload: false,
      toBottomTab
    };
    if (isRefreshInsteadOfPush) {
      refresh(to, params, options);
    } else if (isReplaceInsteadOfPush) {
      replace(to, params, options);
    } else {
      push(to, params, options);
    }
    isPushing.current = false;
  }, [toBottomTab, onCustomPress, isRefreshInsteadOfPush, isReplaceInsteadOfPush, refresh, to, params, replace, push]);
  const onPressInExternal = (rest === null || rest === void 0 ? void 0 : rest.onPressIn) || undefined;
  const onPressIn = React.useCallback(e => {
    preloadElementInner();
    preload(to, params);
    onPressInExternal === null || onPressInExternal === void 0 ? void 0 : onPressInExternal(e);
  }, [to, preload, preloadElementInner, params, onPressInExternal]);
  if (skipLinkBehaviourIfPressIsDefined && onCustomPress) {
    return children({
      onPress: onCustomPress,
      onPressIn: onPressInExternal
    });
  }
  return children({
    onPress: onPress,
    onPressIn: rest.onPressIn || onPressIn
  });
}
//# sourceMappingURL=Link.js.map