"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useBottomTabsStateNavigator = useBottomTabsStateNavigator;
var React = _interopRequireWildcard(require("react"));
var _navigationReact = require("navigation-react");
var _navigation = require("navigation");
var _RidgeNavigationContext = _interopRequireDefault(require("../contexts/RidgeNavigationContext"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
function useBottomTabsStateNavigator(startKey) {
  const {
    goToUrl
  } = React.useContext(_RidgeNavigationContext.default);
  const {
    stateNavigator
  } = React.useContext(_navigationReact.NavigationContext);
  const navigator = React.useRef(function () {
    const n = new _navigation.StateNavigator(stateNavigator);
    n.start(startKey);
    return n;
  }());
  React.useEffect(() => {
    const isCurrentBottomTabs = goToUrl === null || goToUrl === void 0 ? void 0 : goToUrl.startsWith('/' + startKey);
    if (goToUrl && isCurrentBottomTabs) {
      const parsedRootUrl = navigator.current.parseLink(goToUrl);
      let fluentBottomNavigator = navigator.current.fluent(false);
      const crumbs = [...parsedRootUrl.crumbs];
      if (crumbs.length === 0) {
        return undefined;
      }
      fluentBottomNavigator = fluentBottomNavigator.navigate(startKey);
      crumbs.forEach(crumb => {
        fluentBottomNavigator = fluentBottomNavigator.navigate(crumb.state.key, crumb.data);
      });
      fluentBottomNavigator = fluentBottomNavigator.navigate(parsedRootUrl.state.key, parsedRootUrl.data);

      // we need to wait till bottom tab is switched
      const timerId = setTimeout(() => {
        navigator.current.navigateLink(fluentBottomNavigator.url);
      }, 50);
      return () => clearTimeout(timerId);
    }
    return undefined;
  }, [goToUrl, startKey]);
  return navigator.current;
}
//# sourceMappingURL=useBottomTabsStateNavigator.js.map