"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createBottomTabsRoot = createBottomTabsRoot;
exports.createNormalRoot = createNormalRoot;
exports.createScreens = createScreens;
exports.fluentRootBottomTabs = fluentRootBottomTabs;
exports.fluentRootNormal = fluentRootNormal;
exports.fluentScreen = fluentScreen;
exports.generatePath = generatePath;
exports.getBottomTabKeyFromPath = getBottomTabKeyFromPath;
exports.getBreakingPointFromRoot = getBreakingPointFromRoot;
exports.getParams = getParams;
exports.getPathFromUrl = getPathFromUrl;
exports.getPaths = getPaths;
exports.getRootKeyFromPath = getRootKeyFromPath;
exports.getScreenKey = getScreenKey;
exports.makeVariablesNavigationFriendly = makeVariablesNavigationFriendly;
exports.partMatches = partMatches;
exports.registerScreen = registerScreen;
exports.rootKeyAndPaths = rootKeyAndPaths;
exports.skipUrlSegment = skipUrlSegment;
exports.splitPath = splitPath;
exports.useAboveBreakingPoint = useAboveBreakingPoint;
var _reactNative = require("react-native");
// export interface RootChildSideMenu {
//   type: 'sideMenu';
//   children: SideMenuItem[];
// }

function createBottomTabsRoot(children, extra) {
  return {
    type: 'bottomTabs',
    children,
    components: extra === null || extra === void 0 ? void 0 : extra.components,
    breakingPointWidth: extra === null || extra === void 0 ? void 0 : extra.breakingPointWidth
  };
}
function createNormalRoot(child) {
  return {
    type: 'normal',
    child
  };
}
function registerScreen(path, element, preload, options) {
  return {
    path,
    element,
    preload,
    options
  };
}
function createScreens(screenMap) {
  return Object.keys(screenMap).map(key => {
    return screenMap[key];
  });
}
function skipUrlSegment(tab, screenPath) {
  if (!tab) {
    return false;
  }
  return tab.child.path === screenPath;
}
function getScreenKey(rootKey, tab) {
  for (var _len = arguments.length, paths = new Array(_len > 2 ? _len - 2 : 0), _key = 2; _key < _len; _key++) {
    paths[_key - 2] = arguments[_key];
  }
  const firstPath = (paths === null || paths === void 0 ? void 0 : paths[0]) || (tab === null || tab === void 0 ? void 0 : tab.child.path);
  const skipSegment = skipUrlSegment(tab, firstPath);
  const screenPath = skipSegment ? undefined : firstPath;
  return rootKeyAndPaths(rootKey, tab === null || tab === void 0 ? void 0 : tab.path, screenPath);
}
function rootKeyAndPaths(rootKey) {
  const sanitizedRoot = rootKey.endsWith('/') ? rootKey.slice(0, -1) : rootKey; // Remove trailing slash from rootKey
  for (var _len2 = arguments.length, paths = new Array(_len2 > 1 ? _len2 - 1 : 0), _key2 = 1; _key2 < _len2; _key2++) {
    paths[_key2 - 1] = arguments[_key2];
  }
  const sanitizedPaths = paths.filter(p => p).map(path => {
    const trimmedPath = path.trim();
    const withoutLeadingSlash = trimmedPath.startsWith('/') ? trimmedPath.slice(1) : trimmedPath;
    const withoutTrailingSlash = withoutLeadingSlash.endsWith('/') ? withoutLeadingSlash.slice(0, -1) : withoutLeadingSlash;
    return withoutTrailingSlash;
  }); // Remove leading and trailing slashes from paths

  const url = sanitizedRoot + '/' + sanitizedPaths.join('/');
  return url;
}
function makeVariablesNavigationFriendly(s) {
  // replace :id with {id} and so on
  return s.replace(/:([^/]+)/g, '{$1}');
}
function generatePath(path, params) {
  // replace :id with params[key]
  return path.replace(/:([^/]+)/g, (_match, key) => {
    return params[key] || 'undefined-param';
  });
}
function getRootKeyFromPath(path) {
  return splitPath(path)[0];
}
function getBottomTabKeyFromPath(path) {
  var _splitPath;
  return (_splitPath = splitPath(path)) === null || _splitPath === void 0 ? void 0 : _splitPath[1];
}
function getPaths(path, hasBottomTabs) {
  const paths = splitPath(path);
  // 0 = rootKey
  // 1 = bottomTabKey
  return paths.filter((_, index) => {
    if (hasBottomTabs) {
      return index >= 2;
    }
    return index >= 1;
  });
}
function splitPath(path) {
  let splitMatchPath = path.split('/').filter(p => p);
  return splitMatchPath;
}
function getPathFromUrl(url) {
  if (url.startsWith('/')) {
    // web
    return url;
  }
  if (url.startsWith('http://') || url.startsWith('https://')) {
    const u = new URL(url);
    return u.pathname + u.search;
  }
  if (url.includes('://')) {
    const split = url.split('://');
    return '/' + split[1];
  }
  return '/' + url;
}
function partMatches(urlPart, routePart) {
  // url part does not exist
  if (urlPart === undefined || routePart === undefined) {
    return false;
  }

  // is parameter in url match everything
  if (routePart.startsWith(':')) {
    return true;
  }
  return routePart === urlPart;
}
function getParams(urlPathSplit, routePathSplit) {
  let params = {};
  routePathSplit.forEach((routePath, i) => {
    if (routePath.startsWith(':')) {
      const paramKey = routePath.substring(1);
      params[paramKey] = urlPathSplit[i];
    }
  });
  return params;
}
const defaultBreakingPoint = 1200;
function getBreakingPointFromRoot(v) {
  let configuredBreakingPoint;
  if ((v === null || v === void 0 ? void 0 : v.type) === 'bottomTabs') {
    configuredBreakingPoint = v.breakingPointWidth;
  }

  // user explicitly set the breaking point to null, so we never will make sure the breaking point will never happen
  if (configuredBreakingPoint === null) {
    configuredBreakingPoint = Infinity;
  }
  return configuredBreakingPoint || defaultBreakingPoint;
}
function useAboveBreakingPoint(breakingPoint) {
  const {
    width
  } = (0, _reactNative.useWindowDimensions)();
  return width > breakingPoint;
}
function fluentRootBottomTabs(rootKey, tab) {
  return {
    rootKey,
    tab
  };
}
function fluentRootNormal(rootKey) {
  return {
    rootKey
  };
}
function fluentScreen(screen, params) {
  return {
    screen,
    params
  };
}
//# sourceMappingURL=navigationUtils.js.map