import * as React from 'react';
import useNavigation from './useNavigation';
export default function Link(_ref) {
  let {
    to,
    toBottomTab,
    params,
    children,
    onPress: onCustomPress,
    skipLinkBehaviourIfPressIsDefined,
    replace: isReplaceInsteadOfPush,
    refresh: isRefreshInsteadOfPush,
    ...rest
  } = _ref;
  const isPushing = React.useRef(false);
  const {
    push,
    replace,
    refresh,
    preload,
    preloadElement
  } = useNavigation();
  const preloadElementInner = React.useCallback(() => {
    preloadElement(to);
  }, [preloadElement, to]);
  const onPress = React.useCallback(async event => {
    // we don't want to go to another screen but we do want preloading
    // behaviour of the Link component :)
    // e.g. a modal with same data dependencies as the list screen
    if (onCustomPress) {
      onCustomPress(event);
      return;
    }
    if (isPushing.current) {
      return;
    }
    isPushing.current = true;
    const options = {
      preload: false,
      toBottomTab
    };
    if (isRefreshInsteadOfPush) {
      refresh(to, params, options);
    } else if (isReplaceInsteadOfPush) {
      replace(to, params, options);
    } else {
      push(to, params, options);
    }
    isPushing.current = false;
  }, [toBottomTab, onCustomPress, isRefreshInsteadOfPush, isReplaceInsteadOfPush, refresh, to, params, replace, push]);
  const onPressInExternal = (rest === null || rest === void 0 ? void 0 : rest.onPressIn) || undefined;
  const onPressIn = React.useCallback(e => {
    preloadElementInner();
    preload(to, params);
    onPressInExternal === null || onPressInExternal === void 0 ? void 0 : onPressInExternal(e);
  }, [to, preload, preloadElementInner, params, onPressInExternal]);
  if (skipLinkBehaviourIfPressIsDefined && onCustomPress) {
    return children({
      onPress: onCustomPress,
      onPressIn: onPressInExternal
    });
  }
  return children({
    onPress: onPress,
    onPressIn: rest.onPressIn || onPressIn
  });
}
//# sourceMappingURL=Link.js.map