import { NavigationHandler } from 'navigation-react';
import NavigationStack from './navigation/NavigationStack';
import OptimizedContext, { OptimizedContextProvider } from './contexts/OptimizedContext';
import * as React from 'react';
import RidgeNavigationContext from './contexts/RidgeNavigationContext';
import { createNormalRoot, makeVariablesNavigationFriendly, rootKeyAndPaths } from './navigationUtils';
import { StateNavigator } from 'navigation';
import { Text } from 'react-native';
import HiddenNavbarWithSwipeBack from './HiddenNavbarWithSwipeBack';
function NavigationNestedProvider(_ref) {
  let {
    children
  } = _ref;
  const id = React.useId();
  const rootKey = 'navigationModalProvider_' + id.replace(':', '--');
  const {
    theme
  } = React.useContext(OptimizedContext);
  const {
    screens,
    navigationRoot,
    ...rest
  } = React.useContext(RidgeNavigationContext);
  const rootNavigator = React.useMemo(() => {
    const stateInfos = [{
      key: rootKey,
      route: rootKey,
      trackCrumbTrail: false,
      renderScene: () => /*#__PURE__*/React.createElement(EmptyElement, null),
      preloadId: rootKey
    }, ...screens.map(screen => ({
      key: rootKeyAndPaths(rootKey, screen.path),
      route: makeVariablesNavigationFriendly(rootKeyAndPaths(rootKey, screen.path)),
      renderScene: () => /*#__PURE__*/React.createElement(screen.element, null),
      trackCrumbTrail: true,
      preloadId: screen.path
    }))];
    const navigator = new StateNavigator(stateInfos);
    navigator.historyManager.disabled = true;
    navigator.historyManager.stop();
    navigator.navigate(rootKey);
    return navigator;
  }, [rootKey, screens]);
  const navigationRootWithModal = React.useMemo(() => ({
    [rootKey]: createNormalRoot({
      path: rootKey,
      preload: () => {},
      element: EmptyElement
    }),
    ...navigationRoot
  }), [navigationRoot, rootKey]);
  return /*#__PURE__*/React.createElement(RidgeNavigationContext.Provider, {
    value: {
      screens,
      ...rest,
      rootNavigator,
      navigationRoot: navigationRootWithModal
    }
  }, /*#__PURE__*/React.createElement(NavigationHandler, {
    stateNavigator: rootNavigator
  }, /*#__PURE__*/React.createElement(NavigationStack, {
    underlayColor: theme.layout.backgroundColor,
    backgroundColor: () => theme.layout.backgroundColor
    //@ts-ignore
    ,
    renderWeb: key => key === rootKey ? children : undefined,
    renderScene: (state, data) => {
      return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(HiddenNavbarWithSwipeBack, null), /*#__PURE__*/React.createElement(OptimizedContextProvider, {
        withSuspenseContainer: false,
        state: state,
        data: data
      }, state.key === rootKey ? children : state.renderScene()));
    }
  })));
}
function EmptyElement() {
  return /*#__PURE__*/React.createElement(Text, null, "Empty");
}
export default NavigationNestedProvider;
//# sourceMappingURL=NavigationNestedProvider.js.map