import type { ComponentType, FC, ReactNode } from 'react';
import type { PressableProps, GestureResponderEvent } from 'react-native';
export type ExtractRouteParams<T extends string> = string extends T ? Record<string, string> : T extends `${infer Start}:${infer Param}/${infer Rest}` ? {
    [k in Param | keyof ExtractRouteParams<Rest>]: string;
} : T extends `${infer Start}:${infer Param}` ? {
    [k in Param]: string;
} : {};
export interface BaseScreen {
    path: string;
    element: ComponentType;
    preload: (params: any) => any;
    options?: ScreenOptions;
}
export interface FluentParams {
    rootKey: string;
    tab?: BottomTabType;
}
export interface FluentScreen {
    screen: BaseScreen;
    params: ExtractRouteParams<BaseScreen['path']>;
}
export interface BottomTabType {
    child: BaseScreen;
    path: string;
    title: () => string;
    icon?: any;
    selectedIcon?: any;
}
export type BottomTabComponent = FC<{
    orientation: Orientation;
}>;
export type BottomTabOverrideComponent = FC<BottomTabOverrideProps>;
export type BottomTabOverrideProps = {
    originalBottomTabs: ReactNode;
    orientation: Orientation;
    children: any;
};
export interface BottomTabComponents {
    start?: BottomTabComponent;
    end?: BottomTabComponent;
    override?: BottomTabOverrideComponent;
}
export interface SideMenuItem {
    child: BaseScreen;
    title: () => string;
    icon: string;
}
export interface RootChildBottomTabs {
    type: 'bottomTabs';
    children: BottomTabType[];
    components?: BottomTabComponents;
    breakingPointWidth: undefined | null | number;
}
export interface RootChildNormal {
    type: 'normal';
    child: BaseScreen;
}
export type Orientation = 'vertical' | 'horizontal';
export declare function createBottomTabsRoot(children: BottomTabType[], extra?: {
    components?: BottomTabComponents;
    breakingPointWidth?: number | null;
} | undefined | null): RootChildBottomTabs;
export declare function createNormalRoot(child: BaseScreen): RootChildNormal;
export type RootValue = RootChildNormal | RootChildBottomTabs;
export type Root = Record<string, RootValue>;
export type ScreenOptions = {
    title?: string;
    description?: string;
};
export declare function registerScreen<Path extends string, E extends ComponentType, Preload extends (params: ExtractRouteParams<Path>) => void>(path: Path, element: E, preload: Preload, options?: ScreenOptions): {
    path: Path;
    element: E;
    preload: Preload;
    options: ScreenOptions | undefined;
};
export type LinkRenderProps = {
    onPressIn?: (event: GestureResponderEvent) => void;
    onHoverIn?: (event: any) => void;
    onPress: (event: GestureResponderEvent) => void;
    accessibilityRole?: 'link';
    href?: string;
};
export type LinkProps<T extends BaseScreen> = {
    to: T;
    toBottomTab?: BottomTabType;
    params: ExtractRouteParams<T['path']>;
    children: (p: LinkRenderProps) => any;
    linkMode?: 'default' | 'sensitive';
    onPress?: PressableProps['onPress'];
    onPressIn?: PressableProps['onPressIn'];
    onHoverIn?: PressableProps['onHoverIn'];
    skipLinkBehaviourIfPressIsDefined?: boolean;
    replace?: boolean;
    refresh?: boolean;
};
export type BottomTabLinkRenderProps = LinkRenderProps & {
    isSelected: boolean;
    testID?: string;
};
export type BottomTabLinkProps<T extends BottomTabType> = {
    to: BottomTabType;
    params: ExtractRouteParams<T['child']['path']>;
    children: (p: BottomTabLinkRenderProps) => any;
    mode?: 'default' | 'sensitive';
    onPress?: PressableProps['onPress'];
};
export declare function createScreens(screenMap: Record<string, BaseScreen>): BaseScreen[];
export declare function skipUrlSegment(tab: BottomTabType | undefined, screenPath: string | undefined): boolean;
export declare function getScreenKey(rootKey: string, tab: BottomTabType | undefined, ...paths: (string | undefined)[]): string;
export declare function rootKeyAndPaths(rootKey: string, ...paths: (string | undefined)[]): string;
export declare function makeVariablesNavigationFriendly(s: string): string;
export declare function generatePath(path: string, params: Record<string, string>): string;
export declare function getRootKeyFromPath(path: string): string | undefined;
export declare function getBottomTabKeyFromPath(path: string): string | undefined;
export declare function getPaths(path: string, hasBottomTabs: boolean): string[];
export declare function splitPath(path: string): string[];
export declare function getPathFromUrl(url: string): string;
export declare function partMatches(urlPart: string | undefined, routePart: string | undefined): boolean;
export declare function getParams(urlPathSplit: string[], routePathSplit: string[]): Record<string, string>;
export declare function getBreakingPointFromRoot(v?: RootValue): number;
export declare function useAboveBreakingPoint(breakingPoint: number): boolean;
export declare function fluentRootBottomTabs(rootKey: string, tab?: BottomTabType): FluentParams;
export declare function fluentRootNormal(rootKey: string): FluentParams;
export declare function fluentScreen<T extends BaseScreen>(screen: T, params: ExtractRouteParams<T['path']>): FluentScreen;
//# sourceMappingURL=navigationUtils.d.ts.map